@@ -129,7 +129,7 @@ EphyDialogProperty properties [] =
 
 	/* Privacy */
 	{ "popups_allow_checkbutton",		CONF_SECURITY_ALLOW_POPUPS,	  PT_AUTOAPPLY, 0 },
-	{ "enable_java_checkbutton",		CONF_SECURITY_JAVA_ENABLED,	  PT_AUTOAPPLY, 0 },
+	{ "enable_plugins_checkbutton",		CONF_SECURITY_PLUGINS_ENABLED,	  PT_AUTOAPPLY, 0 },
 	{ "enable_javascript_checkbutton",	CONF_SECURITY_JAVASCRIPT_ENABLED, PT_AUTOAPPLY, 0 },
 	{ "cookies_radiobutton",		CONF_SECURITY_COOKIES_ACCEPT,	  PT_AUTOAPPLY, G_TYPE_STRING },
 	{ "remember_passwords_checkbutton",	CONF_PRIVACY_REMEMBER_PASSWORDS,  PT_AUTOAPPLY, 0 },
@@ -241,7 +241,7 @@ prefs_dialog_show_help (EphyDialog *dialog)
 	id = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
 	id = CLAMP (id, 0, 3);
 
-	ephy_gui_help (GTK_WINDOW (window), "epiphany", help_preferences[id]);
+	ephy_gui_help (window, help_preferences[id]);
 }
 
 static void
@@ -906,13 +906,16 @@ download_path_changed_cb (GtkFileChooser *button)
 	desktop_dir = ephy_file_desktop_dir ();
 	g_return_if_fail (downloads_dir != NULL && desktop_dir != NULL);
 
+	/* Check if the dir matches the default downloads_dir or desktop_dir to
+	 * store the english name instead of the localized one reported by the
+	 * two ephy_file_ functions. */
 	if (strcmp (dir, downloads_dir) == 0)
 	{
-		eel_gconf_set_string (CONF_STATE_DOWNLOAD_DIR, "Downloads");
+		eel_gconf_set_string (CONF_STATE_DOWNLOAD_DIR, _("Downloads"));
 	}
 	else if (strcmp (dir, desktop_dir) == 0)
 	{
-		eel_gconf_set_string (CONF_STATE_DOWNLOAD_DIR, "Desktop");
+		eel_gconf_set_string (CONF_STATE_DOWNLOAD_DIR, _("Desktop"));
 	}
 	else
 	{
@@ -1018,7 +1021,7 @@ prefs_homepage_current_button_clicked_cb (GtkWidget *button,
           (EPHY_EMBED_CONTAINER (window));
 	g_return_if_fail (embed != NULL);
 
-	set_homepage_entry (dialog, ephy_web_view_get_address (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed)));
+	set_homepage_entry (dialog, ephy_web_view_get_address (ephy_embed_get_web_view (embed)));
 }
 
 static void
